@@ -196,7 +196,7 @@ def create_tfrecord_unlabeled(out_filename, addrs, ids, IMAGE_SIZE = (192,192)):
 		#feature creation
 		feature = {
 			'image' : _bytes_feature(img.tostring()),
-			'idnum' : _bytes_feature(idnum.numpy())
+			'idnum' : _bytes_feature(idnum.encode())
 		}
 
 		# example protocol buffer
