@@ -2,6 +2,7 @@ def get_models_training_report(models,tpu, n_class, traindata, steps_per_epoch,
 	
 	import pandas as pd
 	import numpy as np
+	import gc
 	from load_models_quick import create_model
 	print("Num classes => " , n_class)
 	print("\n\n", '#'*90, '\n\n')
@@ -22,6 +23,11 @@ def get_models_training_report(models,tpu, n_class, traindata, steps_per_epoch,
 
 
 		history = model.fit(traindata, steps_per_epoch = steps_per_epoch, epochs = epochs,batch_size = batch_size, validation_data =  val_data, verbose = 0)
+		tf.keras.backend.clear_session()
+		tf.compat.v1.reset_default_graph()
+		del model
+		gc.collect()
+		
 		df = df.append(pd.DataFrame([[m, history.history[metrics][-1], np.mean(history.history[metrics][-3:]) , history.history['val_' + metrics][-1], np.mean(history.history['val_' + metrics][-3:])]], columns = ['Model_Name', 'Accuracy_top1', 'Accuracy_top3', "Val_Accuracy_top1", "Val_Accuracy_top3"]), ignore_index = True)
 		print(f"Done with model -> {m}")
 
